@@ -133,15 +133,23 @@ class QuicknoteProgram(hildonize.get_app_class()):
 			help_menu.show()
 			help_menu.set_submenu(helpmenu)
 
-			menu_bar = gtk.MenuBar()
-			menu_bar.show()
-			menu_bar.append (file_menu)
-			menu_bar.append (category_menu)
-			menu_bar.append (view_menu)
-			menu_bar.append (help_menu)
+			menuBar = gtk.MenuBar()
+			menuBar.show()
+			menuBar.append (file_menu)
+			menuBar.append (category_menu)
+			menuBar.append (view_menu)
+			menuBar.append (help_menu)
 
-			menu_bar.show()
-			vbox.pack_start(menu_bar, False, False, 0)
+			vbox.pack_start(menuBar, False, False, 0)
+		else:
+			menuBar = gtk.MenuBar()
+			menuBar.show()
+
+			moveToCategoryButton = gtk.Button(_("Move To Category"))
+			moveToCategoryButton.connect("clicked", self._on_move_category, None)
+
+			deleteCategoryButton = gtk.Button(_("Delete Category"))
+			deleteCategoryButton.connect("clicked", self._on_delete_category, None)
 
 		#Create GUI elements
 		self._topBox = kopfzeile.Kopfzeile(self._db)
@@ -165,12 +173,13 @@ class QuicknoteProgram(hildonize.get_app_class()):
 
 		self._window = hildonize.hildonize_window(self, self._window)
 		hildonize.set_application_title(self._window, "%s" % constants.__pretty_app_name__)
-		if hildonize.GTK_MENU_USED:
-			menu_bar = hildonize.hildonize_menu(
-				self._window,
-				menu_bar,
-				[]
-			)
+		menuBar = hildonize.hildonize_menu(
+			self._window,
+			menuBar,
+		)
+		if hildonize.IS_FREMANTLE_SUPPORTED:
+			menuBar.append(moveToCategoryButton)
+			menuBar.append(deleteCategoryButton)
 
 		if not hildonize.IS_HILDON_SUPPORTED:
 			_moduleLogger.info("No hildonization support")
@@ -305,23 +314,27 @@ class QuicknoteProgram(hildonize.get_app_class()):
 				self._window.unfullscreen ()
 			else:
 				self._window.fullscreen ()
+			return True
 		elif (
 			event.keyval == gtk.keysyms.F7 or
 			event.keyval == gtk.keysyms.i and isCtrl
 		):
 			# Zoom In
 			self.enable_zoom(True)
+			return True
 		elif (
 			event.keyval == gtk.keysyms.F8 or
 			event.keyval == gtk.keysyms.o and isCtrl
 		):
 			# Zoom Out
 			self.enable_zoom(False)
+			return True
 		elif event.keyval == ord("l") and event.get_state() & gtk.gdk.CONTROL_MASK:
 			with open(constants._user_logpath_, "r") as f:
 				logLines = f.xreadlines()
 				log = "".join(logLines)
 				self._clipboard.set_text(str(log))
+			return True
 
 	@gtk_toolbox.log_exception(_moduleLogger)
 	def _on_view_sql_history(self, widget = None, data = None, data2 = None):
@@ -343,46 +356,47 @@ class QuicknoteProgram(hildonize.get_app_class()):
 		sqldiag.destroy()
 
 	@gtk_toolbox.log_exception(_moduleLogger)
-	def _on_move_category(self, widget = None, data = None):
-		dialog = gtk.Dialog(_("Choose category"), self._window, gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT, (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT, gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
-
-		dialog.set_position(gtk.WIN_POS_CENTER)
+	def _on_move_category(self, *args):
 		comboCategory = gtk.combo_box_new_text()
-
 		comboCategory.append_text('undefined')
 		sql = "SELECT id, liste FROM categories WHERE id = 0 ORDER BY liste"
 		rows = self._db.ladeSQL(sql)
 		for row in rows:
 			comboCategory.append_text(row[1])
 
-		dialog.vbox.pack_start(comboCategory, True, True, 0)
+		dialog = gtk.Dialog(_("Choose category"), self._window, gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT, (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT, gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
+		try:
+			dialog.set_position(gtk.WIN_POS_CENTER)
 
-		dialog.vbox.show_all()
-		#dialog.set_size_request(400, 300)
+			dialog.vbox.pack_start(comboCategory, True, True, 0)
+			dialog.vbox.show_all()
 
-		if dialog.run() == gtk.RESPONSE_ACCEPT:
-			n = comboCategory.get_active()
-			if -1 < n and self._notizen.noteId != -1:
-				model = comboCategory.get_model()
-				active = comboCategory.get_active()
-				if active < 0:
-					return None
-				cat_id = model[active][0]
+			userResponse = dialog.run()
+		finally:
+			dialog.destroy()
 
-				noteid, category, note = self._db.loadNote(self._notizen.noteId)
-				#print noteid, category, cat_id
-				self._db.saveNote(noteid, note, cat_id, pcdatum = None)
-				self._topBox.category_combo_changed()
-			else:
-				mbox = gtk.MessageDialog(self._window, gtk.DIALOG_MODAL, gtk.MESSAGE_ERROR, gtk.BUTTONS_OK, _("No note selected."))
-				response = mbox.run()
-				mbox.hide()
-				mbox.destroy()
+		if userResponse != gtk.RESPONSE_ACCEPT:
+			return
 
-		dialog.destroy()
+		n = comboCategory.get_active()
+		if -1 < n and self._notizen.noteId != -1:
+			model = comboCategory.get_model()
+			active = comboCategory.get_active()
+			if active < 0:
+				return None
+			cat_id = model[active][0]
+
+			noteid, pcdatum, category, note = self._db.loadNote(self._notizen.noteId)
+			self._db.saveNote(noteid, note, cat_id, pcdatum = None)
+			self._topBox.category_combo_changed()
+		else:
+			mbox = gtk.MessageDialog(self._window, gtk.DIALOG_MODAL, gtk.MESSAGE_ERROR, gtk.BUTTONS_OK, _("No note selected."))
+			response = mbox.run()
+			mbox.hide()
+			mbox.destroy()
 
 	@gtk_toolbox.log_exception(_moduleLogger)
-	def _on_delete_category(self, widget = None, data = None):
+	def _on_delete_category(self, *args):
 		if self._topBox.get_category() == "%" or self._topBox.get_category() == "undefined":
 			mbox = gtk.MessageDialog(None, gtk.DIALOG_MODAL, gtk.MESSAGE_ERROR, gtk.BUTTONS_OK, _("This category can not be deleted"))
 			response = mbox.run()
